<?php

namespace Essentials\Core;

use Essentials\Data;
use Essentials\Templates;

class Framework {

	/**
	 * @var Framework
	 */
	public static $instance;

	/**
	 * @var Config
	 */
	private $config;

	/**
	 * @var Context
	 */
	private $context;

	/**
	 * @var \TitanFramework
	 */
	private $titan_instance;

	/**
	 * @param $context Context
	 * @param $config  Config
	 */
	public function __construct($context, $config) {
		$this->config  = $config;
		$this->context = $context;

		global $content_width;
		$content_width = isset($config->common->$content_width) ? $config->common->$content_width : 1140;

		Support::init(isset($this->config->common->support) ? $this->config->common->support : array());
		Data\Menu::init(isset($this->config->common->menus) ? $this->config->common->menus : array());

		add_action('after_setup_theme', array($this, 'init'));
		add_action('tf_create_options', array($this, 'titan'));
	}

	public function init() {
		//$this->config = apply_filters('void-framework-config', $this->config);

		Data\Sidebar::init($this->context, $this->config);
		Data\Post_Type::init($this->config->post_types, $this->context->theme->TextDomain);
		Data\Taxonomy::init($this->config->taxonomies, $this->context->theme->TextDomain);

		//Data\Term_Meta::init($this->context, $this->config);

		if (!($this->context->is_admin || $this->context->is_login)) {
			// Frontend
			Templates\Layout::init($this->config->layouts, $this->context);
			Templates\Assets::init($this->config->assets, $this->context);
		}
	}

	public function titan() {
		if (!isset($this->titan_instance)) {
			$this->titan_instance = \TitanFramework::getInstance($this->context->theme->Template);
		}

		Data\Customizer::init($this->context, $this->config, $this->titan_instance);
		Data\Options::init($this->context, $this->config, $this->titan_instance);
		Data\Post_Meta::init($this->context, $this->config, $this->titan_instance);
	}

	public function get_config() {
		return $this->config;
	}

	/**
	 * @param $context Context
	 * @param $config  Config
	 */
	public static function create($context, $config) {
		Framework::$instance = new Framework($context, $config);
	}
}