<?php

namespace Essentials\Data;

use Essentials\Utils\Once;

class Base_Entity
{
    /**
     * @var string Entity name
     */
    protected $name;

    /**
     * @var string Singular name for UI
     */
    protected $singular;

    /**
     * @var string Plural name for UI
     */
    protected $plural;

    /**
     * @var string Text domain for translations
     */
    protected $text_domain;

    /**
     * @var array Settings for registering
     */
    protected $settings;


    /**
     * Base entity constructor
     * @param object $options Custom entity options
     * @param string $text_domain Text domain. Unique identifier for retrieving translated strings
     */
    protected function __construct($options, $text_domain)
    {
        # Check post type name
        if (isset($options->name)) {
            $options->name = strtolower($options->name);
        } else {
            return null;
        }

        $this->name = $options->name;
        $this->text_domain = $text_domain;
        $this->singular = isset($options->singular) ? $options->singular : ucwords(str_replace('_', ' ', $this->name));
        $this->plural = isset($options->plural) ? $options->plural : "{$this->singular}s";
    }

    /**
     * Translate string using text domain
     * @param string $string String to translate
     * @return string|void
     */
    protected function translate($string)
    {
        return _x($string, $this->name, $this->text_domain);
    }

    /**
     * Compose common settings for register
     * @param array $defaults Default settings
     * @param object $options Custom entity options
     * @param array $labels An array of labels for this entity
     * @return array
     */
    protected function parse_common_settings($defaults, $options, $labels)
    {
        $settings = array_merge($defaults, isset($options->args) ? get_object_vars($options->args) : array());

        # Labels
        $settings['label'] = isset($settings['label']) ? $settings['label'] : $this->plural;

        if (isset($options->labels)) {
            $labels = array_merge($labels, get_object_vars($options->labels));
        }

        foreach ($labels as &$label) {
            $label = $this->translate($label);
        }

        unset($label);

        $settings['labels'] = $labels;

        # Rewrite
        if (isset($settings['rewrite'])) {
            $settings['rewrite'] = get_object_vars($settings['rewrite']);

            Once::add_action('after_switch_theme', 'flush_rewrite_rules');
        }

        return $settings;
    }
}