<?php

namespace Essentials\Data;

use Essentials\Utils\Condition;

final class Customizer
{

    /**
     * @var \Essentials\Core\Context
     */
    private $context;

    /**
     * @var array
     */
    private $settings;

    /**
     * @param $context \Essentials\Core\Context
     * @param $settings array
     * @param $titan \TitanFramework
     */
    private function __construct($context, $settings, $titan)
    {
        if (!is_array($settings)) {
            return;
        }

        $this->context = $context;
        $this->settings = $settings;

        /* Customizer */

        foreach ($this->settings as $id => $parameters) {
            if(isset($parameters['dependency']) && !Condition::check($parameters['dependency']['type'], $parameters['dependency']['value'])) {
                continue;
            }

            $section = $titan->createThemeCustomizerSection(array(
                'id' => $id,
                'name' => isset($parameters['name']) ? $parameters['name'] : $id,
                'position' => isset($parameters['position']) ? $parameters['position'] : 30,
                'panel' => isset($parameters['panel']) ? $parameters['panel'] : null
            ));

            foreach ($parameters['options'] as $meta_box_option) {
                $section->createOption($meta_box_option);
            }
        }
    }

    /**
     * @param $context \Essentials\Core\Context
     * @param $config \Essentials\Core\Config
     * @param $titan \TitanFramework
     */
    public static function init($context, $config, $titan)
    {
        $settings = $config::make_array($config->customizer);

        $settings = apply_filters('om_customizer_settings', $settings);

        new Customizer($context, $settings, $titan);
    }
}