<?php

namespace Essentials\Data;

use Essentials\Utils\Condition;

final class Post_Meta
{
    /**
     * @var \Essentials\Core\Context
     */
    private $context;

    /**
     * @var array
     */
    private $settings;

    /**
     * @param $context \Essentials\Core\Context
     * @param $settings array
     * @param $titan \TitanFramework
     */
    private function __construct($context, $settings, $titan)
    {
        if (!is_array($settings)) {
            return;
        }

        $this->context = $context;
        $this->settings = $settings;

        foreach ($this->settings as $post_meta_box) {
            if(isset($post_meta_box['dependency']) && !Condition::check($post_meta_box['dependency']['type'], $post_meta_box['dependency']['value'])) {
                continue;
            }

            $meta_box = $titan->createMetaBox(array(
                'name' => $post_meta_box['name'],
                'post_type' => $post_meta_box['post_type'],

                'capability' => empty($post_meta_box['capability']) ? 'manage_options' : $post_meta_box['capability'], // User role
                'icon' => empty($post_meta_box['icon']) ? 'dashicons-admin-generic' : $post_meta_box['icon'], // Menu icon for top level menus only
                'position' => empty($post_meta_box['position']) ? 100.01 : $post_meta_box['position'], // Menu position for top level menus only
                'context' => empty($post_meta_box['context']) ? 'normal' : $post_meta_box['context'], // normal, advanced, or side
                'priority' => empty($post_meta_box['priority']) ? 'high' : $post_meta_box['priority'], //  high, core, default, low
                'desc' => empty($post_meta_box['desc']) ? '' : $post_meta_box['desc']
            ));

            foreach ($post_meta_box['options'] as $meta_box_option) {
                $meta_box->createOption($meta_box_option);
            }
        }
    }

    /**
     * @param $context \Essentials\Core\Context
     * @param $config \Essentials\Core\Config
     * @param $titan \TitanFramework
     */
    public static function init($context, $config, $titan)
    {
        $settings = $config::make_array($config->post_meta);

        $settings = apply_filters('om_post_meta_settings', $settings);

        new Post_Meta($context, $settings, $titan);
    }
}