<?php
/**
 * Created by PhpStorm.
 * User: ori
 * Date: 04.05.15
 * Time: 15:50
 */

namespace Essentials\Data;

// TODO: Update needed: use WordPress functions instead of "wpdb"
class Term_Meta
{
    /**
     * @var Term_Meta
     */
    private static $instance;

    /**
     * @var \Essentials\Core\Context
     */
    private $context;

    /**
     * @var \Essentials\Core\Config
     */
    private $config;

    /**
     * @var \wpdb
     */
    private $wpdb;

    /**
     * @var string
     */
    private $table;

    /**
     * @param $context \Essentials\Core\Context
     * @param $config \Essentials\Core\Config
     */
    public function __construct($context, $config)
    {
        $this->context = $context;
        $this->config = $config;

        $this->init_database();

        //foreach ($this->settings as $post_meta_box) {
        /*$meta_box = $titan->createMetaBox(array(
            'name' => $post_meta_box['name'],
            'post_type' => $post_meta_box['post_type'],
        ));

        foreach ($post_meta_box['options'] as $meta_box_option) {
            $meta_box->createOption($meta_box_option);
        }*/
        //}
    }

    private function init_database()
    {
        global $wpdb;

        $this->wpdb = $wpdb;
        $this->table = $this->wpdb->prefix . 'ome_term_meta';

        if (!get_option($this->table)) {

            $charset_collate = $this->wpdb->get_charset_collate();

            $sql = "CREATE TABLE IF NOT EXISTS $this->table (
                      meta_id bigint(20) unsigned NOT NULL auto_increment,
                      term_id bigint(20) unsigned NOT NULL default '0',
                      meta_key varchar(255) default NULL,
                      meta_value longtext,
                      PRIMARY KEY  (meta_id),
                      KEY term_id (term_id),
                      KEY meta_key (meta_key)
                    ) $charset_collate;";

            require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
            dbDelta($sql);

            update_option($this->table, true);
        }
    }

    /**
     * @param $context \Essentials\Core\Context
     * @param $config \Essentials\Core\Config
     */
    public static function init($context, $config)
    {
        self::$instance = new Term_Meta($context, $config);
    }

    /**
     * @param $id int|array Term id or list of term ids
     * @param $key string Meta key
     * @return mixed
     */
    public static function get($id, $key)
    {
        // Make sure everything is valid.
        if (!$key || !(is_numeric($id) || is_array($id))) {
            return false;
        }

        if(is_numeric($id)) {
            $id = absint($id);
        }

        if(is_array($id)) {
            $id = array_filter(array_map('absint', $id));
        }

        if (!$id) {
            return false;
        }

        if (!is_string($key)) {
            return false;
        }

        $value = null;

        $instance = self::$instance;

        if (is_array($id)) {
            $ids = implode(',', $id);

            $metas = $instance->wpdb->get_results(
                $instance->wpdb->prepare("SELECT term_id, meta_value FROM $instance->table WHERE term_id IN ($ids) AND meta_key = %s", $key)
            );

            $value = array();

            foreach($metas as $meta) {
                $value[$meta->term_id] = $meta->meta_value;
            }

        } else if (is_int((int)$id)) {
            $value = $instance->wpdb->get_var(
                $instance->wpdb->prepare("SELECT meta_value FROM $instance->table WHERE term_id = %s AND meta_key = %s", $id, $key)
            );

            $value = maybe_unserialize($value);
        }

        return $value;
    }


    /**
     * @param $id int Term id or list of term ids
     * @param $key string Meta key
     * @param $value string Meta value
     * @return mixed
     */
    public static function set($id, $key, $value)
    {
        // Make sure everything is valid.
        if (!$key || !is_numeric($id)) {
            return false;
        }

        $id = absint($id);
        if (!$id) {
            return false;
        }

        $instance = self::$instance;

        $meta_id = $instance->wpdb->get_var(
            $instance->wpdb->prepare("SELECT meta_id FROM $instance->table WHERE term_id = %s AND meta_key = %s", $id, $key)
        );

        $value = maybe_serialize($value);

        $instance->wpdb->replace($instance->table, array(
            'meta_id' => $meta_id,
            'term_id' => $id,
            'meta_key' => $key,
            'meta_value' => $value
        ), array('%d', '%d', '%s', '%s'));

        return $value;
    }
}