<?php

namespace Essentials\Html;

class Writer
{
    /**
     * Content
     * @var string
     */
    private $html = '';

    /**
     * Array of non-closed tags
     * @var array
     */
    private $closes = array();

    /**
     * Constructor
     */
    public function __construct()
    {
        return $this;
    }

    /**
     * Convert array of attributes to string
     * @param array $attributes attributes
     * @return string
     */
    private function get_attributes_string($attributes)
    {
        $string = '';

        if (!is_null($attributes)) {
            foreach ($attributes as $key => $value) {
                $string .= ' ' . $key;

                if (!is_null($value)) {
                    $string .= '="' . $value . '"';
                }
            }
        }

        return $string;
    }

    /**
     * Create new element
     * @param string $tag Tag name
     * @param string|array $attributes Attributes
     * @param string $text
     * @param string $closed
     * @return $this
     */
    private function element($tag, $attributes = '', $text, $closed)
    {
        $end_tag = "</$tag>";
        $slash = '';
        $close_tag = '';

        if ($closed) {
            if (isset($text)) {
                $close_tag = $end_tag;
            } else {
                $slash = '/';
            }
        } else {
            $this->closes[] = $end_tag;
        }

        $this->html .= "<$tag{$attributes}{$slash}>$text{$close_tag}";

        return $this;
    }

    /**
     * Create new instance of Html class
     * @return $this
     */
    public static function init()
    {
        return new Writer();
    }

    /**
     * Clear all
     * @return $this
     */
    public function clear()
    {
        $this->html = '';
        $this->closes = array();

        return $this;
    }

    /**
     * Close last opened tag or some number tags
     * @param boolean|int $all if true than all tags, if number than count, otherwise one
     * @return $this
     */
    public function end($all = false)
    {
        if ($all) {
            $all = is_int($all) ? $all : count($this->closes);

            while ($this->closes && $all--) {
                $this->html .= array_pop($this->closes);
            }
        } else if (!empty($this->closes)) {
            $this->html .= array_pop($this->closes);
        }

        return $this;
    }

    /**
     * Insert an html
     * @param array|\Essentials\Html\Writer $html an \UI\Html_Writer object or array of its
     * @return $this
     */
    public function html($html)
    {
        if (!is_array($html)) {
            $html = array($html);
        }

        foreach ($html as $part) {
            $part = (object)$part;

            $this->html .= $part->__toString();
        }

        return $this;
    }

    /**
     * Insert text
     * @param string $text
     * @return $this
     */
    public function text($text)
    {
        $this->html .= $text;

        return $this;
    }

    /**
     * Return finalized html string
     * @return string
     */
    public function to_string()
    {
        return $this->__toString();
    }

    /**
     * Render html
     */
    public function out() {
        echo $this->__toString();
    }

    /**
     * Return finalized html string
     * @return string
     */
    public function __toString()
    {
        return $this->end(true)->html;
    }

    /**
     * Magic method used to generate HTML tags
     * @param string $name name of called function
     * @param array $arguments array of parameters
     * @return $this
     */
    public function __call($name, $arguments)
    {
        $last = end($arguments);

        $attributes = '';
        $closed_tag = false;
        $text = null;

        if ('/' == $last) {
            $closed_tag = true;
            array_pop($arguments);
        }

        $count = count($arguments);

        if ($count > 0) {
            if (is_array($arguments[0])) {
                if (isset($arguments[0]['text'])) {
                    $text = $arguments[0]['text'];
                    unset($arguments[0]['text']);
                }

                $attributes = $this->get_attributes_string($arguments[0]);
            } else {
                $attributes = ' ' . $arguments[0];
            }

            if ($count > 1) {
                $text = (string)$arguments[1];
            }
        }

        $this->element($name, $attributes, $text, $closed_tag);

        return $this;
    }
}