<?php

namespace Essentials\Templates;

use Essentials\Core\Context;

class Layout
{
    /**
     * @var Layout Current layout object
     */
    public static $current;

    /**
     * @var array Layout settings
     */
    public static $settings;

    /**
     * @var Context
     */
    public static $context;

    /**
     * @var array Dynamic template data
     */
    public static $data = array();

    /**
     * @var string
     */
    private $body;

    /**
     * @var string
     */
    private $layout;

    /**
     * @var array
     */
    private $sections;

    /**
     * @var bool Any mobile device
     */
    public $is_mobile;

    /**
     * @var bool Any phone device
     */
    public $is_phone;

    /**
     * @var bool Any tablet device
     */
    public $is_tablet;

    /**
     * @param string $body
     */
    public function __construct($body)
    {
        $detect = new \Mobile_Detect();

        $this->is_mobile = $detect->isMobile();
        $this->is_tablet = $this->is_mobile && $detect->isTablet();
        $this->is_phone = $this->is_mobile && !$this->is_tablet;

        // get template name
        $template = basename($body, '.php');

        $this->body = $template;

        // search settings for current template
        foreach (self::$settings as $setting) {
            if (!isset($setting->templates)) {
                $this->layout = $setting->layout;
                $this->sections = $setting->sections;

            } elseif (in_array($template, $setting->templates)) {
                if (isset($setting->layout)) {
                    $this->layout = $setting->layout;
                }

                $this->sections = array_merge($this->sections, $setting->sections);
            }
        }
    }

    private function locate($file) {
        if ($this->is_mobile) {
            if ($this->is_phone) {
                $template = locate_template($file . '.phone.php');
            } elseif ($this->is_tablet) {
                $template = locate_template($file . '.tablet.php');
            }

            if (empty($template)) {
                $template = locate_template($file . '.mobile.php');
            }
        }

        if (empty($template)) {
            $template = locate_template($file . '.php');
        }

        return $template;
    }

    /**
     * Load template file
     *
     * @param string $file Template file path
     * @return string if $buffer, return render result as string, otherwise print
     */
    private function load($file)
    {
        $template = $this->locate($file);

        load_template($template, true);
    }

    /**
     * Initialize layout system
     *
     * @param $settings array Layout settings
     * @param $context Context
     */
    public static function init($settings, $context)
    {
        foreach ($settings as &$setting) {
            if (isset($setting->sections) && is_object($setting->sections)) {
                $setting->sections = get_object_vars($setting->sections);
            }
        }

        unset($setting);

        self::$settings = $settings;
        self::$context = $context;

        add_filter('template_include', array('Essentials\Templates\Layout', 'wrap'), 99);
    }

    public static function wrap($body)
    {
        $layout = new Layout($body);

        self::$current = $layout;

        return $layout->locate($layout->layout);
    }

    public static function render($name = 'body')
    {
        $layout = self::$current;

        if ($name == 'body') {
            $layout->load($layout->body);
        } else {
            if (isset($layout->sections[$name])) {
                $layout->load($layout->sections[$name]);
            }
        }
    }

    public static function get_template_name() {
        return self::$current->body;
    }
}