<?php

use Essentials\Data\Term_Meta;

function om_render_image_field($id, $value)
{
    if (is_numeric($value)) {
        $image = om_get_image($value, array(150, 150));
        $url = $image['150x150']['url'];
    } else {
        $value = '';
    }

    echo '<div class="tf-upload">';

    $previewImage = '';
    if (isset($url)) {
        $previewImage = "<i class='dashicons dashicons-no-alt remove'></i><img src='" . esc_url($url) . "' style='display: none'/>";
    }
    echo "<div class='thumbnail tf-image-preview'>" . $previewImage . "</div>";

    printf("<input name=\"%s\" id=\"%s\" type=\"hidden\" value=\"%s\" />",
        $id,
        $id,
        esc_attr($value)
    );

    echo '</div>';

    ?>
    <script>
        jQuery(document).ready(function ($) {
            "use strict";

            function tfUploadOptionCenterImage($this) {
                // console.log('preview image loaded');
                var height = $this.height(),
                    width = $this.width(),
                    _preview = $this.parents('.tf-upload').find('.thumbnail').css('text-align', 'center'),
                    previewHeight = _preview.height(),
                    previewWidth = _preview.width();

                if (height < previewHeight && width <= previewWidth) {
                    $this.css({
                        'marginTop': (previewHeight - height) / 2,
                        'marginLeft': (previewWidth - width) / 2
                    });
                }
                $this.show();
            }


            // Calculate display offset of preview image on load
            $('.tf-upload .thumbnail img').load(function () {
                tfUploadOptionCenterImage($(this));
            }).each(function () {
                // Sometimes the load event might not trigger due to cache
                if (this.complete) {
                    $(this).trigger('load');
                }
            });


            // In the theme customizer, the load event above doesn't work because of the accordion,
            // the image's height & width are detected as 0. We bind to the opening of an accordion
            // and adjust the image placement from there.
            var tfUploadAccordionSections = [];
            $('.tf-upload').each(function () {
                var $accordion = $(this).parents('.control-section.accordion-section');
                if ($accordion.length > 0) {
                    if ($.inArray($accordion, tfUploadAccordionSections) == -1) {
                        tfUploadAccordionSections.push($accordion);
                    }
                }
            });
            $.each(tfUploadAccordionSections, function () {
                var $title = $(this).find('.accordion-section-title:eq(0)'); // just opening the section
                $title.click(function () {
                    var $accordion = $(this).parents('.control-section.accordion-section');
                    if (!$accordion.is('.open')) {
                        $accordion.find('.tf-upload .thumbnail img').each(function () {
                            var $this = $(this);
                            setTimeout(function () {
                                tfUploadOptionCenterImage($this);
                            }, 1);
                        });
                    }
                });
            });


            // remove the image when the remove link is clicked
            $('body').on('click', '.tf-upload i.remove', function (event) {
                event.preventDefault();
                var _input = $(this).parents('.tf-upload').find('input');
                var _preview = $(this).parents('.tf-upload').find('div.thumbnail');

                _preview.find('img').remove().end().find('i').remove();
                _input.val('').trigger('change');

                return false;
            });


            /*open the upload media lightbox when the upload button is clicked*/
            $('body').on('click', '.tf-upload .thumbnail, .tf-upload img', function (event) {
                event.preventDefault();
                // If we have a smaller image, users can click on the thumbnail
                if ($(this).is('.thumbnail')) {
                    if ($(this).parents('.tf-upload').find('img').length != 0) {
                        $(this).parents('.tf-upload').find('img').trigger('click');
                        return true;
                    }
                }

                var _input = $(this).parents('.tf-upload').find('input');
                var _preview = $(this).parents('.tf-upload').find('div.thumbnail');
                var _remove = $(this).siblings('.tf-upload-image-remove');

                // uploader frame properties
                var frame = wp.media({
                    title: '<?php esc_js(__( 'Select Image', TF_I18NDOMAIN )) ?>',
                    multiple: false,
                    library: {type: 'image'},
                    button: {text: '<?php esc_js(__( 'Use image', TF_I18NDOMAIN )) ?>'}
                });

                // get the url when done
                frame.on('select', function () {
                    var selection = frame.state().get('selection');
                    selection.each(function (attachment) {
                        if (_input.length > 0) {
                            _input.val(attachment.id);
                        }

                        if (_preview.length > 0) {
                            // remove current preview
                            if (_preview.find('img').length > 0) {
                                _preview.find('img').remove();
                            }
                            if (_preview.find('i.remove').length > 0) {
                                _preview.find('i.remove').remove();
                            }

                            // Get the preview image
                            var image = attachment.attributes.sizes.full;
                            if (typeof attachment.attributes.sizes.thumbnail != 'undefined') {
                                image = attachment.attributes.sizes.thumbnail;
                            }
                            var url = image.url;
                            var marginTop = ( _preview.height() - image.height ) / 2;
                            var marginLeft = ( _preview.width() - image.width ) / 2;

                            $("<img src='" + url + "'/>")
                                .css('marginTop', marginTop)
                                .css('marginLeft', marginLeft)
                                .appendTo(_preview);
                            $("<i class='dashicons dashicons-no-alt remove'></i>").prependTo(_preview);
                        }
                        // we need to trigger a change so that WP would detect that we changed the value
                        // or else the save button won't be enabled
                        _input.trigger('change');

                        _remove.show();
                    });
                    frame.off('select');
                });

                // open the uploader
                frame.open();

                return false;
            });
        });
    </script>
<?php
}

add_action('project_category_add_form_fields', function () {

    echo '<div class="form-field"><label for="icon">Category Icon</label>';
    om_render_image_field('icon', '');
    echo '</div>';
});

add_action('project_category_edit_form_fields', function ($category) {

    $icon = Term_Meta::get($category->term_id, 'icon');

    echo '<tr class="form-field"><th valign="top" scope="row"><label for="icon">Category Icon</label></th><td>';
    om_render_image_field('icon', $icon);
    echo '</td></tr>';
});

add_action('create_project_category', 'om_save_project_category_fields');
add_action('edit_project_category', 'om_save_project_category_fields');

function om_save_project_category_fields($category_id)
{
    $icon = sanitize_text_field($_POST['icon']);

    Term_Meta::set($category_id, 'icon', $icon);
}